@@ -6,6 +6,7 @@
 #include <libgnomevfs/gnome-vfs-address.h>
 #include <libgnomevfs/gnome-vfs-resolve.h>
 #include <libgnomevfs/gnome-vfs-dns-sd.h>
+#include <libgnomevfs/gnome-vfs-async-ops.h>
 #include <pyorbit.h>
 
 static GHashTable *monitor_hash;
@@ -2269,6 +2270,8 @@ register_constants(PyObject *module)
     regconst(FILE_INFO_FIELDS_CTIME);
     regconst(FILE_INFO_FIELDS_SYMLINK_NAME);
     regconst(FILE_INFO_FIELDS_MIME_TYPE);
+    regconst(FILE_INFO_FIELDS_ACCESS);
+    regconst(FILE_INFO_FIELDS_IDS);
     regconst(PERM_SUID);
     regconst(PERM_SGID);
     regconst(PERM_STICKY);
@@ -2289,6 +2292,8 @@ register_constants(PyObject *module)
     regconst(FILE_INFO_FORCE_FAST_MIME_TYPE);
     regconst(FILE_INFO_FORCE_SLOW_MIME_TYPE);
     regconst(FILE_INFO_FOLLOW_LINKS);
+    regconst(FILE_INFO_GET_ACCESS_RIGHTS);
+    regconst(FILE_INFO_NAME_ONLY);
     regconst(SET_FILE_INFO_NONE);
     regconst(SET_FILE_INFO_NAME);
     regconst(SET_FILE_INFO_PERMISSIONS);
@@ -2364,6 +2369,13 @@ register_constants(PyObject *module)
     regconst(XFER_PHASE_COMPLETED);
     regconst(DIRECTORY_KIND_DESKTOP);
     regconst(DIRECTORY_KIND_TRASH);
+    regconst(PERM_ACCESS_READABLE);
+    regconst(PERM_ACCESS_WRITABLE);
+    regconst(PERM_ACCESS_EXECUTABLE);
+    regconst(PRIORITY_MIN);
+    regconst(PRIORITY_MAX);
+    regconst(PRIORITY_DEFAULT);
+
 #undef regconst
 }
 
